@@ -28,5 +28,14 @@ coxsplitss=function(y, id, nfolds){
   
   foldid <- full$foldid
   
+  return(foldid)
+}
+
+fgfoldid=function(id, foldid){
+  idfoldid <- data.frame(id=unique(id),foldid=foldid)
+  yfoldid <- data.frame(id=id)
+  mergedid <- yfoldid %>% left_join(idfoldid,by="id")
+  
+  foldid <- mergedid$foldid
   return(foldid)
 }
\ No newline at end of file
